package com.neusoft.smart.pos.card.persistent.domain;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class CardCapitalChangeExtExample {

	protected String orderByClause;

	protected boolean distinct;

	protected List<Criteria> oredCriteria;

	private Integer offset;

	private Integer limit;

	public CardCapitalChangeExtExample() {
		oredCriteria = new ArrayList<Criteria>();
	}
	
	public void setOrderByClause(String orderByClause) {
		this.orderByClause = orderByClause;
	}
	
	public String getOrderByClause() {
		return orderByClause;
	}
	
	public void setDistinct(boolean distinct) {
		this.distinct = distinct;
	}
	
	public boolean isDistinct() {
		return distinct;
	}
	
	public List<Criteria> getOredCriteria() {
		return oredCriteria;
	}
	
	public void or(Criteria criteria) {
		oredCriteria.add(criteria);
	}
	
	public Criteria or() {
		Criteria criteria = createCriteriaInternal();
		oredCriteria.add(criteria);
		return criteria;
	}
	
	public Criteria createCriteria() {
		Criteria criteria = createCriteriaInternal();
		if (oredCriteria.size() == 0) {
			oredCriteria.add(criteria);
		}
		return criteria;
	}
	
	protected Criteria createCriteriaInternal() {
		Criteria criteria = new Criteria();
		return criteria;
	}
	
	public void clear() {
		oredCriteria.clear();
		orderByClause = null;
		distinct = false;
		this.offset = null;
		this.limit = null;
	}
	
	public Integer getOffset() {
		return this.offset;
	}
	
	public void setOffset(Integer offset) {
		this.offset = offset;
	}
	
	public Integer getLimit() {
		return this.limit;
	}
	
	public void setLimit(Integer limit) {
		this.limit = limit;
	}
	
	public CardCapitalChangeExtExample page(int offset, int limit) {
		this.offset = offset;
		this.limit = limit;
		return this;
	}
	
	protected abstract static class GeneratedCriteria {
		
		protected List<Criterion> criteria;
		
		protected GeneratedCriteria() {
			super();
			criteria = new ArrayList<Criterion>();
		}
		
		public boolean isValid() {
			return criteria.size() > 0;
		}
		
		public List<Criterion> getAllCriteria() {
			return criteria;
		}
		
		public List<Criterion> getCriteria() {
			return criteria;
		}
		
		protected void addCriterion(String condition) {
			if (condition == null) {
				throw new RuntimeException("Value for condition cannot be null");
			}
			criteria.add(new Criterion(condition));
		}
		
		protected void addCriterion(String condition, Object value, String property) {
			if (value == null) {
				throw new RuntimeException("Value for " + property + " cannot be null");
			}
			criteria.add(new Criterion(condition, value));
		}
		
		protected void addCriterion(String condition, Object value1, Object value2, String property) {
			if (value1 == null || value2 == null) {
				throw new RuntimeException("Between values for " + property + " cannot be null");
			}
			criteria.add(new Criterion(condition, value1, value2));
		}
		public Criteria andMemberCardIdEqualTo(Integer value) {
			addCriterion("mcr.card_id =", value, "cardId");
			return (Criteria) this;
		}
		
		public Criteria andMemberIdEqualTo(Integer value) {
			addCriterion("m.member_id =", value, "memberId");
			return (Criteria) this;
		}
		
		public Criteria andMemberIdIn(List<Integer> values) {
			addCriterion("m.member_id in ", values, "memberId");
			return (Criteria) this;
		}
		
		public Criteria andChangeTimeBetween(Date value1, Date value2) {
			addCriterion("ccc.change_time between", value1, value2, "changeTime");
			return (Criteria) this;
		}
		
		public Criteria andChangeTypeEqualTo(Integer value) {
			addCriterion("ccc.change_type =", value, "changType");
			return (Criteria) this;
		}
		
		public Criteria andChangeTypeIn(List<Integer> values) {
			addCriterion("ccc.change_type in ", values, "changType");
			return (Criteria) this;
		}
		
		public Criteria andMemberOrgIdEqualTo(Integer value) {
			addCriterion("m.member_org_id =", value, "memberOrgId");
			return (Criteria) this;
		}
		
		public Criteria andMemberStoreIdIn(List<Integer> values) {
			addCriterion("m.member_store_id in ", values, "memberStoreId");
			return (Criteria) this;
		}
		
		public Criteria andMemberStoreIdIsNotNull() {
			addCriterion("m.member_store_id is not null");
			return (Criteria) this;
		}
		
	}
	
	public static class Criteria extends GeneratedCriteria {
		
		protected Criteria() {
			super();
		}
	}
	
	public static class Criterion {
		
		private String condition;
		
		private Object value;
		
		private Object secondValue;
		
		private boolean noValue;
		
		private boolean singleValue;
		
		private boolean betweenValue;
		
		private boolean listValue;
		
		private String typeHandler;
		
		public String getCondition() {
			return condition;
		}
		
		public Object getValue() {
			return value;
		}
		
		public Object getSecondValue() {
			return secondValue;
		}
		
		public boolean isNoValue() {
			return noValue;
		}
		
		public boolean isSingleValue() {
			return singleValue;
		}
		
		public boolean isBetweenValue() {
			return betweenValue;
		}
		
		public boolean isListValue() {
			return listValue;
		}
		
		public String getTypeHandler() {
			return typeHandler;
		}
		
		protected Criterion(String condition) {
			super();
			this.condition = condition;
			this.typeHandler = null;
			this.noValue = true;
		}
		
		protected Criterion(String condition, Object value, String typeHandler) {
			super();
			this.condition = condition;
			this.value = value;
			this.typeHandler = typeHandler;
			if (value instanceof List<?>) {
				this.listValue = true;
			} else {
				this.singleValue = true;
			}
		}
		
		protected Criterion(String condition, Object value) {
			this(condition, value, null);
		}
		
		protected Criterion(String condition, Object value, Object secondValue, String typeHandler) {
			super();
			this.condition = condition;
			this.value = value;
			this.secondValue = secondValue;
			this.typeHandler = typeHandler;
			this.betweenValue = true;
		}
		
		protected Criterion(String condition, Object value, Object secondValue) {
			this(condition, value, secondValue, null);
		}
	}
}